@@ -1,5 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
+ * Copyright (C) 2007 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,33 +18,178 @@
  */
 
 #include <ncursesw/ncurses.h>
-#include <ncursesw/menu.h>
 #include <ncursesw/form.h>
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <sys/stat.h>
-#include <dirent.h>
 #include <string.h>
-#include <nl_types.h>
+#include <unistd.h>
 
-#include "gettext.h"
+#include <dirent.h>
+#include <nl_types.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <fcntl.h>
 #include <libintl.h>
 
+#include "gettext.h"
 #include "thread.h" /* run_command() */
 #include "cdw_widgets.h" /* nice_box() */
 #include "cdw_ui.h"
+#include "processwin.h"
 #include "options.h" /* struct conf */
 #include "config.h"
 #include "main.h" /* clean_before_cdw_exit() */
 #include "utils.h"
+#include "cdw_cdio.h"
+#include "commands.h"
+
+
+extern struct conf config;
+extern WINDOW mainwin;
+extern enum current_command_t current_command;
+
+
+/**
+ * Copy audio tracks to separate files
+ *
+ * Copy all tracks from audio CD to separate files in selected directory.
+ * The files are verbatim copies of disc tracks, so their parameters are
+ * following:
+ *
+ * 2 channels
+ * 44100 samples per second
+ * 16 bit signed pcm
+ * little endian (intel)
+ *
+ * This function is poor man's version of cdda2wav(), it only rips tracks,
+ * user have to convert them to some other format by himself.
+ *
+ * Track files are written to config->audiodir directory.
+ *
+ * \returns 0 if it tried to rip tracks (even if it failed),
+ *         -1 if some errors ocurred before trying to rip tracks
+ */
+int poor_man_cdda2wav(void)
+{
+	bool success = true;
+	struct disc_information *disc = cdw_cdio_disc_open(config.scsi);
+	if (disc == (struct disc_information *) -1) {
+		/* 2TRANS: this is title of dialog window */
+		dialogbox(_("Message"),
+			  /* 2TRANS: this is message in dialog window */
+			  _("This disc type is not supported."), DIALOG_OK);
+		return -1;
+	} else if (disc == (struct disc_information *) -2) {
+		/* 2TRANS: this is title of dialog window */
+		dialogbox(_("Message"),
+			  /* 2TRANS: this is message in dialog window: disc
+			     is in drive, but cdw cannot open it using a
+			     library API */
+			  _("Cannot open disc."), DIALOG_OK);
+		return -1;
+	}
+
+	current_command = COMMAND_RIP_AUDIO_CD;
+
+	if (disc->mode != CDIO_DISC_MODE_CD_DA) {
+		/* 2TRANS: this is title of dialog window */
+		dialogbox(_("Message"),
+			  /* 2TRANS: this is message in dialog window: user
+			     inserted non-audio disc and wants to perform
+			     operation that should be performed for audio cd */
+			  _("This is not audio CD. Please insert audio CD."), DIALOG_OK);
+		cdw_cdio_disc_close();
+		return -1;
+	}
+
+	char filename[20];
+	/* 2TRANS: this is main part of name of audio tracks ripped from
+	   audio cd, no more than 19 chars */
+	int fnl = strlen(_("track"));
+	if (fnl >= 19) {
+		fnl = 19;
+	}
+	/* 2TRANS: this is main part of name of audio tracks ripped from
+	   audio cd, no more than 19 chars */
+	strncpy(filename, _("track"), fnl);
+	filename[fnl + 1] = '\0';
+
+	cdw_rv_t get_valid_path(char *fullpath, mode_t permissions, int filetype, int n, char *title, char *prompt);
+
+	cdw_rv_t crv = get_valid_path(config.audiodir, /*FIXME - the string is too short */
+			S_IRUSR|S_IWUSR|S_IXUSR, CDW_DIR, 6,
+			/* 2TRANS: this is title of dialog window in which
+                           user has to enter path to valid dir */
+                        _("Output directory"),
+			  /* 2TRANS: this is label in dialog window, below
+			     it is input field */
+			_("Enter path to existing output directory"));
+	if (crv == CDW_OK) {
+		/* 2TRANS: this is title of dialog window where user have to
+		   enter core of track file names */
+		crv = input_box(_("File name"),
+				/* 2TRANS: this is label in dialog window,
+				   below it is an input field */
+				_("Enter core of track file names"), filename, 0);
+		if (crv == CDW_OK) {
+			int i = 0;
+			/* 2TRANS: this is title of dialog window, it is
+			   related to ripping audio CD */
+			processwin_create(_("Copy audio CD"),
+					  /* 2TRANS: this is message in dialog
+					     window: ripping audio cd is in
+					     progress */
+					  _("Copying audio CD..."), true);
+			for (i = disc->first_track; i <= disc->last_track; i++) {
+				char track_info[PROCESSWIN_MAX_TEXT_LEN];
+				/* 2TRANS: this is message in dialog window:
+				   currently track number %d is ripped */
+				sprintf(track_info, _("Copying audio track %d"), i);
+				processwin_display_text_info(track_info, NULL);
+
+				char full_name[330];
+				sprintf(full_name, "%s/%s_%d.raw", config.audiodir, filename, i);
+				/* fprintf(stderr, "\n\noutput raw file name: \"%s\"\n\n", full_name); */
+
+				int fd = open(full_name, O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR);
+				/* perror("open: ");
+				fprintf(stderr, "open returns fd = %d\n", fd); */
+				cdw_rv_t rv = cdw_cdio_read_write_sectors_from_track(disc, i, fd);
+				if (rv != CDW_OK) { /* if any error will occur for any track, then mark whole operation as unsuccesful */
+					/* fprintf(stderr, "track read error for track %d\n", i); */
+					success = false;
+				}
+				close(fd);
+			} /* for */
+
+			cdw_cdio_disc_close();
+
+			if (success) {
+				/* 2TRANS: this is message in dialog window:
+				   ripping audio cd finished successfully */
+				processwin_destroy(_("Finished succesfully"), true);
+			} else {
+				/* 2TRANS: this is message in dialog window:
+				   ripping audio cd finished, but not entirely
+				   successfully */
+				processwin_destroy(_("Finished. Some errors occured."), true);
+			}
+
+			return 0;
+		}
+	}
+
+	cdw_cdio_disc_close();
+
+	return -1;
+}
 
 
 
+#if 0 /* this code was not supported for some time now, I have to disable it */
 
-
-
-int cdda2wav(WINDOW *mainwin, struct conf *config)
+int cdda2wav(void)
 {
 	WINDOW *cddawin;
 	FILE *fp;
@@ -58,12 +204,14 @@ int cdda2wav(WINDOW *mainwin, struct conf *config)
 	FIELD *field[18];
 	FORM *form;
 
-	sprintf(cdinfo, "%s -D%s -J -H -g", CDDA2WAV, config->cdrom);
-	run_command(cdinfo, _("Load CD info..."), 0, 0, 0, "");
+	sprintf(cdinfo, "%s -D%s -J -H -g", CDDA2WAV, config.cdrom);
+	processwin_create(_("Load CD info..."), "", false);
+	run_command(cdinfo);
+	processwin_destroy("", false);
 
-	if ((fp = fopen(config->logfile, "r")) == NULL) {
+	if ((fp = fopen(config.logfile, "r")) == NULL) {
 		clean_before_cdw_exit();
-		fprintf(stderr, _("Cannot open file..."));
+		fprintf(stderr, _("Cannot open log file..."));
 		exit(-1);
 	}
 	line = (char *) malloc(1024);
@@ -91,13 +239,13 @@ int cdda2wav(WINDOW *mainwin, struct conf *config)
 	}
 	wattrset(cddawin, COLOR_PAIR(2));
 
-	sprintf(bpc, "%s", config->bitsperchn);
-	sprintf(brate, "%s", config->bitrate);
-	sprintf(stereo, "%s", config->stereo);
-	sprintf(echo, "%s", config->echosound);
-	sprintf(encode, "%s", config->encode);
-	sprintf(lame, "%s", config->lame);
-	sprintf(highq, "%s", config->highq);
+	sprintf(bpc, "%s", config.bitsperchn);
+	sprintf(brate, "%s", config.bitrate);
+	sprintf(stereo, "%s", config.stereo);
+	sprintf(echo, "%s", config.echosound);
+	sprintf(encode, "%s", config.encode);
+	sprintf(lame, "%s", config.lame);
+	sprintf(highq, "%s", config.highq);
 	sprintf(strk, "%d", start_track);
 	sprintf(etrk, "%d", end_track);
 
@@ -267,81 +415,79 @@ int cdda2wav(WINDOW *mainwin, struct conf *config)
 		case 'g':
 		case 'G':
 			/* mkdir(config.audiodir, S_IRWXU); */
-			if ((directory = opendir(config->audiodir)) == NULL) {
+			if ((directory = opendir(config.audiodir)) == NULL) {
 				if (dialogbox(_("Directory not exist"), _("Audio directory not exist!\nDo you wish to create?"), 3) == BUTTON_OK) {
-					if (mkdir(config->audiodir, S_IRWXU) != 0) {
+					if (mkdir(config.audiodir, S_IRWXU) != 0) {
 						dialogbox(_("Error"), _("Cannot create directory!"), 0);
-						/// wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
 						break;
 					}
-					/// wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
 				} else {
-					/// wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
 					break;
 				}
 			}
 			(void) closedir(directory);
 			wrefresh(cddawin);
 			if (end_track != 0) {
-				sprintf(config->stereo, (!strncmp(field_buffer(field[5], 0), "X", 1) ? "1" : "0"));
-				sprintf(config->bitsperchn, rtrim(field_buffer(field[7], 0)));
-				sprintf(config->echosound, (!strncmp(field_buffer(field[9], 0), "X", 1) ? "1" : "0"));
-				sprintf(config->encode, (!strncmp(field_buffer(field[11], 0), "X", 1) ? "1" : "0"));
-				sprintf(config->highq, (!strncmp(field_buffer(field[13], 0), "X", 1) ? "1" : "0"));
-				sprintf(config->lame, (!strncmp(field_buffer(field[15], 0), "X", 1) ? "1" : "0"));
-				sprintf(config->bitrate, rtrim(field_buffer(field[17], 0)));
+				sprintf((&config)->stereo, (!strncmp(field_buffer(field[5], 0), "X", 1) ? "1" : "0"));
+				sprintf((&config)->bitsperchn, rtrim(field_buffer(field[7], 0)));
+				sprintf((&config)->echosound, (!strncmp(field_buffer(field[9], 0), "X", 1) ? "1" : "0"));
+				sprintf((&config)->encode, (!strncmp(field_buffer(field[11], 0), "X", 1) ? "1" : "0"));
+				sprintf((&config)->highq, (!strncmp(field_buffer(field[13], 0), "X", 1) ? "1" : "0"));
+				sprintf((&config)->lame, (!strncmp(field_buffer(field[15], 0), "X", 1) ? "1" : "0"));
+				sprintf((&config)->bitrate, rtrim(field_buffer(field[17], 0)));
 				start_track = atoi(rtrim(field_buffer(field[1], 0)));
 				end_track = atoi(rtrim(field_buffer(field[3], 0)));
 				write_conf();
 				sprintf(cdinfo, "%s ", CDDA2WAV);
-				if (strncmp(config->stereo, "1", strlen(config->stereo)) == 0)
+				if (strncmp(config.stereo, "1", strlen(config.stereo)) == 0)
 					sprintf(cdinfo, "%s -s", cdinfo);
 				else
 					sprintf(cdinfo, "%s -m", cdinfo);
-				if (strncmp(config->echosound, "1", strlen(config->echosound)) == 0) {
+				if (strncmp(config.echosound, "1", strlen(config.echosound)) == 0) {
 					sprintf(cdinfo, "%s -e", cdinfo);
 				}
-				if (strncmp(config->encode, "1", strlen(config->encode)) == 0) {
-					char msg[30];
+				if (strncmp(config.encode, "1", strlen(config.encode)) == 0) {
 #ifdef OGGENC
+					char msg[30];
 					wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
 					sprintf(cmd, "%s", cdinfo);
 					for (tracknum = start_track; tracknum <= end_track; tracknum++) {
-						if (strncmp(config->highq, "1", strlen(config->highq)) == 0) {
-							sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H - | %s -q 8 -o %s/audio_%.2d.ogg -", cmd, config->cdrom, tracknum, config->bitsperchn, OGGENC,
-								config->audiodir, tracknum);
+						if (strncmp(config.highq, "1", strlen(config.highq)) == 0) {
+							sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H - | %s -q 8 -o %s/audio_%.2d.ogg -", cmd, config.cdrom, tracknum, config.bitsperchn, OGGENC,
+								config.audiodir, tracknum);
 						} else
-							sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H - | %s -b%s -o %s/audio_%.2d.ogg -", cmd, config->cdrom, tracknum, config->bitsperchn, OGGENC,
-								config->bitrate, config->audiodir, tracknum);
+							sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H - | %s -b%s -o %s/audio_%.2d.ogg -", cmd, config.cdrom, tracknum, config.bitsperchn, OGGENC,
+								config.bitrate, config.audiodir, tracknum);
 						sprintf(msg, _("Track: %d"), tracknum);
-						run_command(cdinfo, _("Grab Audio CD"), 0, 0, 1, msg);
+						run_command(cdinfo, _("Grab audio CD"), 0, 0, 1, msg);
 					}
 #endif
-				} else if (strncmp(config->lame, "1", strlen(config->lame)) == 0) {
-					// char msg[30];
+				} else if (strncmp(config.lame, "1", strlen(config.lame)) == 0) {
 #ifdef LAME
+					char msg[30];
 					wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
 					sprintf(cmd, "%s", cdinfo);
 					for (tracknum = start_track; tracknum <= end_track; tracknum++) {
-						if (strncmp(config->highq, "1", strlen(config->highq)) == 0) {
-							sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H - | %s -h -V2 -b%s - %s/audio_%.2d.mp3 -", cmd, config->cdrom, tracknum, config->bitsperchn, LAME,
-								config->bitrate, config->audiodir, tracknum);
+						if (strncmp(config.highq, "1", strlen(config->highq)) == 0) {
+							sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H - | %s -h -V2 -b%s - %s/audio_%.2d.mp3 -", cmd, config.cdrom, tracknum, config.bitsperchn, LAME,
+								config.bitrate, config.audiodir, tracknum);
 						} else
-							sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H - | %s -b%s - %s/audio_%.2d.mp3 -", cmd, config->cdrom, tracknum, config->bitsperchn, LAME,
-								config->bitrate, config->audiodir, tracknum);
+							sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H - | %s -b%s - %s/audio_%.2d.mp3 -", cmd, config.cdrom, tracknum, config.bitsperchn, LAME,
+								config.bitrate, config.audiodir, tracknum);
 						sprintf(msg, _("Track: %d"), tracknum);
-						run_command(cdinfo, _("Grab Audio CD"), 0, 0, 1, msg);
+						run_command(cdinfo, _("Grab audio CD"), 0, 0, 1, msg);
 					}
 #endif
 				} else {
 					char msg[30];
-
-					wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
+					wrefresh(derwin(&mainwin, LINES - 1, COLS - 1, 0, 0));
 					sprintf(cmd, "%s", cdinfo);
 					for (tracknum = start_track; tracknum <= end_track; tracknum++) {
-						sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H %s/audio_%.2d.wav", cmd, config->cdrom, tracknum, bpc, config->audiodir, tracknum);
+						sprintf(cdinfo, "%s -D%s -t%d -b%s -g -H %s/audio_%.2d.wav", cmd, config.cdrom, tracknum, bpc, config.audiodir, tracknum);
 						sprintf(msg, _("Track: %d"), tracknum);
-						run_command(cdinfo, _("Grab Audio CD"), 0, 0, 1, msg);
+						processwin_create(_("Grab Audio CD"), msg, false);
+						run_command(cdinfo);
+						processwin_destroy("", false);
 					}
 				}
 				wrefresh(derwin(cddawin, 15, 60, 0, 0));
@@ -382,4 +528,4 @@ int cdda2wav(WINDOW *mainwin, struct conf *config)
 	return 0;
 }
 
-
+#endif
