@@ -3,7 +3,8 @@
 
 
 #include "options.h"
-int cdda2wav(WINDOW *mainwin, struct conf *config);
+// int cdda2wav(void);
+int poor_man_cdda2wav(void);
 
 
 #endif /* __CDDA2WAW */
