@@ -103,12 +103,12 @@ int size;
 char cdbpass[60];
 char msg[60];
 
-// Function declarations
+/* Function declarations */
 int add_to_dic_sub();
 void show_all();
 void delete_from_db(struct file_list_struct info);
 void insert_disk(char *disk, char *cd_num, char *type);
-// End of function declarations
+/* End of function declarations */
 
 
 #ifdef HAVE_LIBSQLITE
@@ -153,12 +153,12 @@ int add_to_dic()
 	sprintf(msg, "%s %s", config.cdbuser, _("password"));
 	passwd_entered=input_passwd(msg, _("Enter password:"), cdbpass);
     } else
-	passwd_entered=1;
+	passwd_entered=CDW_ENTER;
 #endif
 #ifdef HAVE_LIBSQLITE
-    passwd_entered=1;
+    passwd_entered=CDW_ENTER;
 #endif
-    if (passwd_entered==1){
+    if (passwd_entered==CDW_ENTER){
 	strcpy(cdname, "\0");
 	strcpy(cd_num, "\0");
 	strcpy(category, "none\0");
@@ -254,9 +254,7 @@ void display_error(char *message)
     if (LINES>0) {
 	    dialogbox(_("Error"), message, 0);
     } else {
-#ifdef GTK_GUI
-	gtk_error_dialog(message);
-#endif
+	;
     }
 }
 
@@ -275,10 +273,7 @@ int connect_database()
 	if (LINES>0) {
 		do_create=dialogbox(_("File not exists"), _("SQLite database file not exists!\nMay I create it?"), 3);
 	} else {
-#ifdef GTK_GUI
-	    if (gtk_message(_("SQLite database file not exists!\nMay I create it?"), _("File not exists")))	do_create=0;
-	    else do_create=1;
-#endif
+		;
 	}
     } else {
        fclose(dbfile);
@@ -352,7 +347,7 @@ SQLITE_RES *query_content(char *type, char *disk, char *dir)
 #ifdef HAVE_LIBMYSQLCLIENT
 	if (mysql_query(&mysql, query)) {
 		display_error((char *)mysql_error(&mysql));
-		//fprintf(stderr, "%s: %s\n", _("Failed"), mysql_error(&mysql));
+		/* fprintf(stderr, "%s: %s\n", _("Failed"), mysql_error(&mysql)); */
 		return NULL;
 	} else {
 	    result=mysql_store_result(&mysql);
@@ -1519,9 +1514,9 @@ int cddb_window()
     passwd_entered=input_passwd(msg, _("Enter password:"), cdbpass);
 #endif
 #ifdef HAVE_LIBSQLITE
-    passwd_entered=1;
+    passwd_entered=CDW_ENTER;
 #endif
-    if (passwd_entered==1) {
+    if (passwd_entered==CDW_ENTER) {
 	main_screen();
 	dir_level=0;
 	if (connect_database()!=0){
