@@ -19,7 +19,6 @@
 #include <linux/cdrom.h>
 #include <sys/ioctl.h>
 
-// #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <libintl.h>
@@ -28,20 +27,17 @@
 #include <fcntl.h>
 
 #include <ncursesw/ncurses.h>
-#include <ncursesw/menu.h>
-#include <ncursesw/form.h>
 
-// #include "cdw_ui.h" // dialogbox()
 #include "options.h"
+#include "gettext.h"
 #include "cdw_widgets.h" /* dialogobox() */
 
-#define _(String) gettext(String)
+
 
 extern struct conf config;
-extern WINDOW *mainwin;
 
 
-/*
+/**
  * Check for cdrom drive status
  *
  * Check for cdrom drive status using ioctl (with parameter CDROM_DRIVE_STATUS).
@@ -117,7 +113,7 @@ void close_tray(char *device)
  * Uses dialog box to communicate with user.
  *
  * \returns true if disc is in tray and tray is closed, false if user
- * 	decided to not put disc in drive or drive don't answer
+ * 	decided to not put disc in drive or drive doesnt't answer
  *
  */
 bool disc_in_drive(void)
@@ -133,14 +129,26 @@ bool disc_in_drive(void)
 			case CDS_DISC_OK:
 				return true;
 			case CDS_NO_DISC:
-				rvd = dialogbox(_("CD drive error"), _("No disc in drive. Please insert disc."), DIALOG_OK_CANCEL);
+				/* 2TRANS: this is title of dialog window:
+				   some error occured while trying to
+				   access disc */
+				rvd = dialogbox(_("CD drive error"),
+						/* 2TRANS: this is message in dialog window: no optical disc
+						   found in drive; user can select OK or CANCEL button */
+						_("No disc in drive. Please insert disc."), DIALOG_OK_CANCEL);
 				if (rvd == BUTTON_OK) {
 					break;
 				} else {
 					return false;
 				}
 			case CDS_TRAY_OPEN:
-				rvd = dialogbox(_("CD drive error"), _("Please close CDROM tray."), DIALOG_OK_CANCEL);
+				/* 2TRANS: this is title of dialog window:
+				   some error occured while trying to access
+				   disc */
+				rvd = dialogbox(_("CD drive error"),
+						/* 2TRANS: this is message in dialog window; user
+						   can select OK or CANCEL button */
+						_("Please close CDROM tray."), DIALOG_OK_CANCEL);
 				if (rvd == BUTTON_OK) {
 					break;
 				} else {
@@ -150,7 +158,13 @@ bool disc_in_drive(void)
 				sleep(2);
 				k++;
 				if (k == 5) { /* FIXME: why try 5 times before informing about timeout? */
-					rvd = dialogbox(_("CD drive error"), _("CDROM doesn't respond (timeout). Try again?."), DIALOG_OK_CANCEL);
+					/* 2TRANS: this is title of dialog window:
+					   some error occured while trying to
+					   access disc */
+					rvd = dialogbox(_("CD drive error"),
+							/* 2TRANS: this is message in dialog window;
+							   user can select OK or CANCEL button */
+							_("CDROM doesn't respond (timeout). Try again?"), DIALOG_OK_CANCEL);
 					if (rvd == BUTTON_OK) {
 						k = 0; /* start asking cdrom for response - again */
 						break;
@@ -161,14 +175,26 @@ bool disc_in_drive(void)
 					break; /* silenty try again */
 				}
 			case CDS_NO_INFO:
-				rvd = dialogbox(_("CD drive error"), _("Can't get CDROM info. Continue?"), DIALOG_OK_CANCEL);
+				/* 2TRANS: this is title of dialog window:
+				   some error occured while trying to access
+				   disc */
+				rvd = dialogbox(_("CD drive error"),
+						/* 2TRANS: this is message in dialog window;
+						   cannot read some meta-data from cd; user
+						   can select OK or CANCEL button */
+						_("Can't get CDROM info. Continue?"), DIALOG_OK_CANCEL);
 				if (rvd == BUTTON_OK) { /* user might want to try perform action anyway; let him try, because we are not 100% sure that the action will fail */
 					return true;
 				} else {
 					return false;
 				}
 			default: /* FIXME - is it really our last option? */
-				rvd = dialogbox(_("CD drive error"), _("No disc in drive. Please insert disc."), DIALOG_OK_CANCEL);
+				/* 2TRANS: this is title of dialog window:
+				   some error occured while trying to access
+				   disc */
+				rvd = dialogbox(_("CD drive error"),
+						/* 2TRANS: this is message in dialog window: no optical disc found in drive; user can select OK or CANCEL button */
+						_("No disc in drive. Please insert disc."), DIALOG_OK_CANCEL);
 				if (rvd == BUTTON_OK) {
 					break;
 				} else {
@@ -176,11 +202,13 @@ bool disc_in_drive(void)
 				}
 				break;
 		} /* switch */
-		wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-		select_window(TRUE);
-
 	} /* for */
-	dialogbox(_("CD drive message"), _("Something went wrong.\nPlease check hardware settings in cdw options and try once more."),0);
+	/* 2TRANS: this is message in dialog window:
+	   no optical disc found in drive */
+	dialogbox(_("CD drive message"),
+		  /* 2TRANS: this is message in dialog window: some errors
+		     occured while accessing cd */
+		  _("Something went wrong.\nPlease check hardware settings in cdw options and try once more."), DIALOG_OK);
 	return false; /* user couldn't decide what to do or hardware settings in cdw optins are invalid */
 }
 
