@@ -5,8 +5,8 @@
 #include <sys/ioctl.h>
 
 
-// redefining CDW_* values here so we don't have to include 
-// <linux/cdrom.h> every time when we want to use cdrom_ctrl cdrom_status()
+/* redefining CDW_* values here so we don't have to include */
+/* <linux/cdrom.h> every time when we want to use cdrom_ctrl cdrom_status() */
 #define CDW_CD_NO_INFO CDS_NO_INFO
 #define CDW_CD_NO_DISC  CDS_NO_DISC
 #define CDW_CD_TRAY_OPEN CDS_TRAY_OPEN
@@ -20,4 +20,4 @@ bool disc_in_drive(void);
 
 
 
-#endif // __CDROM_CTRL_H
+#endif /* __CDROM_CTRL_H */
