@@ -30,8 +30,6 @@ int cdw_tmpfile;
 char tmp_file_name[100];
 
 
-
-
 /*
  * Create some temporary files used by cdw to store various data
  *
@@ -41,7 +39,8 @@ char tmp_file_name[100];
  */
 int tmpfiles_init(void)
 {
-	strcpy(tmp_file_name, "/tmp/cdw_tmpfile");
+	memset(tmp_file_name, 100, '\0');
+	sprintf(tmp_file_name, "%s", "/tmp/cdw_tmpfile");
 	return 0;
 }
 
@@ -112,7 +111,7 @@ int filelist_remove(char *path)
 {
 	int i;
 
-	// we are starting from 1 because adding to list was started from 1 too
+	/* we are starting from 1 because adding to list was started from 1 too */
 	for (i = 1; i < FILELIST_SIZE; i++) {
 		if ( filelist[i] != NULL ) {
 			if ( !(strcmp(path, filelist[i])) ) { /* path matched */
