@@ -16,4 +16,4 @@ void filelist_clean(void);
 
 int tmpfiles_init(void);
 
-#endif // __CDW_TMP_FILES_H
+#endif /* __CDW_TMP_FILES_H */
