@@ -3,7 +3,7 @@
 
 enum {
     FIELD_NOT_MATCH=0,
-    FIELD_MATCH,
+    FIELD_MATCH
 };
 
 enum {
@@ -27,11 +27,9 @@ enum {
     CONF_COLOR9_FORE,
     CONF_COLOR9_BG,
     CONF_COLOR10_FORE,
-    CONF_COLOR10_BG,
+    CONF_COLOR10_BG
 };
 
-unsigned char *rtrim(char *str);
-unsigned char *ltrim(char *str);
 void init_curses_colors(void);
 
 #endif
