@@ -10,8 +10,10 @@ int run_command_write_direct(void);
 int run_command_write_audio(void);
 int run_command_copy_disk(void);
 int run_command_blank_cd(void);
-
 int run_command_check_erasable(void);
+void run_command_get_cd_info(void);
+
+int copy_cd_to_image(char *window_title, char *window_message);
 
 
 int prepare_createiso_command(char *command, char *iso_file);
@@ -24,4 +26,17 @@ enum media_erasable_t {
 	MEDIA_ERASABLE_NO
 };
 
+enum current_command_t {
+	COMMAND_NONE,
+	COMMAND_WRITE_DIRECT,
+	COMMAND_WRITE_FROM_IMAGE,
+	COMMAND_WRITE_AUDIO,
+	COMMAND_CREATE_IMAGE,
+	COMMAND_CHECK_ERASABLE,
+	COMMAND_BLANK_CD,
+	COMMAND_COPY_DISK,
+	COMMAND_RIP_AUDIO_CD,
+	COMMAND_COPY_CD_TO_IMAGE
+};
+
 #endif /* __COMMANDS_H */
