@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * A few small modifications (C) 2007 Kamil Ignacak
+ * Copyright (C) 2007 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,18 +48,13 @@
 #include "main.h"
 #include "utils.h"
 #include "cdw_tmp_files.h"
-#include "thread.h"
 #include "cdrom_ctrl.h"
 #include "cdw_ui.h" /* delete_files () */
 
-#ifdef GTK_GUI
-#include "gtkgui.h"
-#endif
 
 #define COLOR_GRAY
 
 
-
 void clean_before_cdw_exit(void);
 int cdw_main_loop(void);
 
@@ -69,7 +64,6 @@ int num;
 extern struct conf config; /* main cdw configuration variable */
 extern WINDOW *mainwin;    /* main application window */
 extern MENU *menu;
-extern MENU *cdmenu;
 
 
 
@@ -94,12 +88,16 @@ int main(int argc, char *argv[])
 	rv = cdw_curses_init();
 	if (rv == -1) {
 		clean_before_cdw_exit();
+		/* 2TRANS: this message displayed in console when program
+		   detects that some requirements are not met, and exits;
+		   please keep '\n' chars */
 		printf(_("\nCannot start cdw: needed min 80x25 terminal!\n"));
-		exit(-1);
+		exit(EXIT_FAILURE);
 	}
 
+
 	/* setup of cdw options module */
-	rv = options_init();
+	rv = preferences_init();
 
 	/* creating new processes in threads code may create some zombie processes */
 	zombie_handler_init();
@@ -116,7 +114,7 @@ int main(int argc, char *argv[])
 	/* main app window */
 	mainform_init();
 
-	select_window(TRUE);
+	select_window(true);
 
 	/*
 	 * initially cursor is on first left-hand menu item, but tooltips are
@@ -155,9 +153,9 @@ void clean_before_cdw_exit(void)
 
 	filelist_clean(); /* list of files to be written to image/disc */
 
-	mainform_clean(); /* main application window */
+	preferences_clean(); /* cdw options module */
 
-	options_clean(); /* cdw options module */
+	mainform_clean(); /* main application window */
 
 	endwin(); /* exit ncurses */
 
@@ -179,21 +177,20 @@ void clean_before_cdw_exit(void)
  */
 int cdw_main_loop(void)
 {
-	char command[555];
-	int c;
-	int rv = 0;
+	int c;      /* input from user */
+	int rv = 0; /* generic return value */
 
-	while (c = wgetch(mainwin)) {
+	while ((c = wgetch(mainwin))) {
 		switch (c) {
 
 			/* -------- HOT KEYS -------- */
+#if 0 /* not in this release */
 #ifdef HAVE_LIBMYSQLCLIENT
 		case 'c':
 		case 'C':
 			/* CDDB */
 			cddb_window();
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(FALSE);
+			main_win_refresh(false);
 			break;
 #endif
 #ifdef HAVE_LIBSQLITE
@@ -201,9 +198,9 @@ int cdw_main_loop(void)
 		case 'C':
 			/* CDDB */
 			cddb_window();
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(FALSE);
+			main_win_refresh(false);
 			break;
+#endif
 #endif
 		case 'e':
 		case 'E':
@@ -215,19 +212,20 @@ int cdw_main_loop(void)
 				eject_tray(config.cdrwdevice);
 			}
 			break;
-#if 0 // not in this release
 		case 'g':
 		case 'G':
 			/* cdda2wav */
-			cdda2wav(mainwin, &config);
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
+			poor_man_cdda2wav();
+			/* cdda2wav(); */
+			main_win_refresh(true);
 			break;
-#endif
 		case 'q':
 		case 'Q':
 			/* this should be the same code as for menu item 'Quit' below */
-			rv = dialogbox(_("Please confirm"), _("Do you really want to quit cdw?"), DIALOG_OK_CANCEL);
+			/* 2TRANS: this is title of dialog window */
+			rv = dialogbox(_("Please confirm"),
+				       /* 2TRANS: this is message in dialog window */
+				       _("Do you really want to quit cdw?"), DIALOG_OK_CANCEL);
 			if (rv == BUTTON_OK) {
 				clean_before_cdw_exit();
 				exit(EXIT_SUCCESS);
@@ -238,63 +236,67 @@ int cdw_main_loop(void)
 			/* sprintf(command, "%s/README.gz", DOCDIR);
 			 * log_window(_("Help"), command, 1); */
 			show_help_main();
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
+			main_win_refresh(false);
 			break;
 		case KEY_F(2):
 			/* Edit volume ID */
-			input_box(_("Volume ID"), _("Enter volume label:"), config.volumeid, 0);
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
+			/* 2TRANS: this is title of dialog window */
+			input_box(_("Volume ID"),
+				  /* 2TRANS: this is message in dialog window,
+				     below is input field for user to enter
+				     CD label */
+				  _("Enter volume label:"), config.volumeid, 0);
 			break;
 		case KEY_F(3):
 			/* Edit other parameters */
-			input_box(_("CD record parameters"), _("Enter parameter:"), config.other, 0);
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
+			/* 2TRANS: this is title of dialog window */
+			input_box(_("CD record parameters"),
+				  /* 2TRANS: this is message in dialog window,
+				     user can enter (in input filed below)
+				     some parameters that will be passed
+				     directly to program called by cdw */
+				  _("Enter parameters:"), config.other, 0);
 			break;
 		case KEY_F(4):
 			/* CD size select */
 			size_selector();
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
 			break;
 		case 'L':
 		case 'l':
 		case KEY_F(5):
 			/* Show last log */
+			/* 2TRANS: this is title of window showing content
+			   of log file with latest messages */
 			log_window(_("Last log"), config.logfile, 0);
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
 			break;
 		case KEY_F(6):
 			/* Show CD info */
-			sprintf(command, "%s dev=%s -atip", CDRECORD, config.scsi);
-			run_command(command, _("Load CD info..."), 0, 0, 0, "");
+			run_command_get_cd_info();
+			/* 2TRANS: this is title of dialog window with some
+			   meta-data about device and about disc currently
+			   in drive */
 			log_window(_("CD info"), config.logfile, 0);
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
 			break;
 /*	    case KEY_F(9):
 		dialogbox("Dialog box", "This is a sample message. Show in a simple\ndialog box\n\nOk?", 3);
-		wrefresh(derwin(mainwin,LINES-1,COLS-1,0,0));
-		select_window(TRUE);
 		break;*/
 
 		case KEY_F(10):
-			/* Show GPL */
-			sprintf(command, "%s/LICENSE", DOCDIR);
-			log_window(_("License"), command, 1);
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
+			{ /* Show GPL */
+				char command[555];
+
+				sprintf(command, "%s/LICENSE", DOCDIR);
+				/* 2TRANS: this is title of dialog window showing cdw license */
+				log_window(_("License"), command, 1);
+			}
 			break;
+#if 0
 #ifdef HAVE_LIBMYSQLCLIENT
 		case 'A':
 		case 'a':
 			/* Add disk to dic database */
 			add_to_dic();
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
+			main_win_refresh(true);
 			break;
 #endif
 #ifdef HAVE_LIBSQLITE
@@ -302,9 +304,9 @@ int cdw_main_loop(void)
 		case 'a':
 			/* Add disk to dic database */
 			add_to_dic();
-			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-			select_window(TRUE);
+			main_win_refresh(true);
 			break;
+#endif
 #endif
 
 		/* ******************************
@@ -328,94 +330,86 @@ int cdw_main_loop(void)
 			display_tooltip(item_index(current_item(menu)));
 			break;
 		case CDW_ENTER:
-			// FIXME - replace 0, 1, 2 etc. with symbolic names
-			/* Add files to list of files to be written to cd/image */
-			if (item_index(current_item(menu)) == 0) {
+			{
+			int ii = item_index(current_item(menu));
+			/* UI_MENU* elements are numbered from 0, so they neatly correspond with menu item numbers */
+
+			if (ii == UI_MENU_ADD_FILES) { /* Add files to list of files to be written to cd/image */
 				put_addwin(getmaxy(mainwin) - 10, getmaxx(mainwin) - 10, (LINES - (getmaxy(mainwin) - 10)) / 2, (COLS - (getmaxx(mainwin) - 10)) / 2);
-				wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-				select_window(TRUE);
-			}
-			/* Delete files from list of files to be written to cd/image */
-			if (item_index(current_item(menu)) == 1) {
+				main_win_refresh(true);
+			} else if (ii == UI_MENU_DELETE_FILES) { /* Delete files from list of files to be written to cd/image */
 				/* if cd files list not empty */
 				if (num > 0) {
-					set_menu_fore(cdmenu, COLOR_PAIR(1) | A_REVERSE);
 					set_menu_fore(menu, COLOR_PAIR(4));
 					wrefresh(mainwin);
 					delete_files();
-					set_menu_fore(cdmenu, COLOR_PAIR(1));
 					set_menu_fore(menu, COLOR_PAIR(4) | A_REVERSE);
 				} else {
-					dialogbox(_("No files to delete"), _("Nothing to delete - no files selected."), DIALOG_OK);
+					/* 2TRANS: this is title of dialog window */
+					dialogbox(_("No files to delete"),
+							/* 2TRANS: this is message in dialog window. User wants to deselect files from list, but there are no files at this time */
+							_("Nothing to delete - no files selected."), DIALOG_OK);
 				}
-			}
-
-			/* Create iso image */
-			if ((item_index(current_item(menu)) == 2)) {
+			} else if (ii == UI_MENU_CREATE_IMAGE) { /* Create iso image */
 				if (num > 0) { /* there are some files on 'selected files' list */
 					rv = conditional_volume_label_dialog();
-					if (rv != CDW_ENTER) {
-						dialogbox(_("Operation canceled"), _("You pressed escape - writing cancelled."), DIALOG_OK);
+					if (rv == CDW_ESCAPE) {
+						/* 2TRANS: this is title of dialog window */
+						dialogbox(_("Operation canceled"),
+								/* 2TRANS: this is message in dialog window. User canceled creating iso image from selected files */
+								_("You pressed escape - writing cancelled."), DIALOG_OK);
 						break;
 					}
 					rv = run_command_create_image();
-					after_event("\"Write to image\" log", 1);
-					if (rv != 0) {
-						break; // FIXME - why break?
+					if ((rv == 0) || (rv == -2)) { /* success or failure (but not cancellation) */
+						/* 2TRANS: this is title of dialog window, showing messages from program writing selected files to iso image (creating iso image from selected files) */
+						after_event("\"Write to image\" log", 1);
 					}
 				} else {
-					dialogbox(_("No files to write"), _("No files selected. Please use 'Add files'"), DIALOG_OK);
+					/* 2TRANS: this is title of dialog window */
+					dialogbox(_("No files to write"),
+							/* 2TRANS: this is message in dialog window: user wants to write files to CD, but there are no selected files */
+							_("No files selected. Please use 'Add files'"), DIALOG_OK);
 				}
-			}
-
-#if 0 // not in this release
-			/* Copy image */
-			if ((item_index(current_item(menu)) == 3)) {
-				int exist = 0;
-				FILE *isofile;
-
-				if ((isofile = fopen(config.tempdir, "r")) != NULL) {
-					exist = dialogbox(_("Image exist"), _("copy: Image file exist!\nDo you wish to overwrite it?"), 3);
-					fclose(isofile);
-				}
-
-				// erase 'Image exists' dialog box window
-				wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-				select_window(FALSE);
-
+			} else if (ii == UI_MENU_COPY_DATA_DISC_TO_IMAGE) { /* Copy content of optical data disc to image file on your hard disc */
 				if (disc_in_drive()) {
-					if (exist == 0) {
-						copy_image(_("Copy CD image"));
-					}
-					wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-					select_window(FALSE);
-					wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-					select_window(FALSE);
+					/* checking if file exists and if can be overwritten
+					is made inside copy_cd_to_image(); FIXME: extract this feature */
+					/* 2TRANS: this is title of dialog window */
+					copy_cd_to_image(_("Copy CD to image"),
+							/* 2TRANS: this is message dialog window, copying data CD to iso file on hdd is in progress */
+							_("Copying disc to iso image..."));
 				}
-				wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-				select_window(FALSE);
-			}
-#endif
-			/* Write selected files to optical disk */
-			if (item_index(current_item(menu)) == 3) {
+			} else if (ii == UI_MENU_RIP_AUDIO_DISC) { /* Copy tracks from optical audio disc to track files on your hard disc */
+				if (disc_in_drive()) {
+					poor_man_cdda2wav();
+				}
+			} else if (ii == UI_MENU_WRITE_TO_DISC) { /* Write selected files or iso image to optical disk */
 				if (!disc_in_drive()) {
 					break;
 				}
 
 				if (strcmp(config.fromimage, "1") == 0) {
-					if (access(config.tempdir, R_OK) == 0) {
+					if (access(config.tempdir, R_OK | W_OK) == 0) {
 						/* Write from image */
 						run_command_write_from_image();
 						eject_tray(config.cdrom);
 						close_tray(config.cdrom);
+						/* 2TRANS: this is title of dialog window, displaying messages from program writing iso image to CD disc */
 						after_event("\"Write image\" log", 1);
 					} else {
-						dialogbox(_("No image file"), _("No image file. Please check your options."), DIALOG_OK);
+						/* 2TRANS: this is title of dialog window */
+						dialogbox(_("No image file"),
+								/* 2TRANS: this is message in dialog window, user wants to write image file to cd, but there is no such file selected, it can be selected in cdw options window */
+								_("No image file. Please check your preferences."), DIALOG_OK);
 					}
 				} else if ((strcmp(config.fromimage, "0") == 0)) {
 					rv = conditional_volume_label_dialog();
 					if (rv == CDW_ESCAPE) {
-						dialogbox(_("Operation canceled"), _("You pressed escape - writing cancelled."), DIALOG_OK);
+						/* 2TRANS: this is title of dialog window */
+						dialogbox(_("Operation canceled"),
+								/* 2TRANS: this is message in dialog window, writing to CD cancelled by user before it even started */
+								_("You pressed escape - writing cancelled."), DIALOG_OK);
 						break;
 					}
 					if ( ! filelist_empty() ){
@@ -423,15 +417,20 @@ int cdw_main_loop(void)
 						run_command_write_direct();
 						eject_tray(config.cdrom);
 						close_tray(config.cdrom);
+						/* 2TRANS: this is title of dialog window showing output messages from program writing to CD*/
 						after_event("\"Write direct\" log", 1);
 					} else {
-						dialogbox(_("No files to write"), _("No files selected. Please use 'Add files'"), DIALOG_OK);
+						/* 2TRANS: this is title of dialog window */
+						dialogbox(_("No files to write"),
+								/* 2TRANS: this is message in dialog window, user wants to write files, but no files from hdd are selected yet */
+								_("No files selected. Please use 'Add files'"), DIALOG_OK);
 					}
 				} else { /* is it really necessary? */
 					;
 				}
 			}
-#if 0 // not in this release
+
+#if 0 /* not in ths release */
 			/* Write Audio */
 			if ((item_index(current_item(menu)) == 5)) {
 				run_command_write_audio();
@@ -441,16 +440,15 @@ int cdw_main_loop(void)
 				run_command_copy_disk();
 			}
 #endif
-			/* Blank CD-RW */
-			if (item_index(current_item(menu)) == 4) {
+
+
+			else if (ii == UI_MENU_BLANK_CDRW) { /* Blank CD-RW */
 				if (!disc_in_drive()) {
 					break;
 				}
 
 				/* prompt user for blank method */
 				rv =  blank_method_selector();
-				wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-				select_window(FALSE);
 
 				if (rv == CDW_ESCAPE) { /* selection of blanking method was cancelled by user */
 					break;
@@ -459,44 +457,42 @@ int cdw_main_loop(void)
 				/* check if disc is erasable;
 				 * possible answers:
 				 * yes (rv = 0), don't know (rv = 0), no (rv != 0) */
-				int rv = run_command_check_erasable();
+				rv = run_command_check_erasable();
 				if (rv == 0) {
 					rv = run_command_blank_cd();
-					wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-					select_window(FALSE);
-					if (rv == 0) { // blanking successful
+					if ((rv == 0) && (!strcmp(config.eject, "1")) ) { /* blanking successful */
 						eject_tray(config.cdrom);
 						close_tray(config.cdrom);
 					}
 				} else {
-					dialogbox(_("Media not erasable"), _("Disc in drive is not erasable. I cannot blank it"), DIALOG_OK);
+					/* 2TRANS: this is title of dialog window */
+					dialogbox(_("Media not erasable"),
+							/* 2TRANS: this is message dialog window, user tries to erase disc that is not erasable */
+							_("Disc in drive is not erasable. Cannot blank it."), DIALOG_OK);
 				}
 
-			}
-
-			/* Edit cdw options */
-			if (item_index(current_item(menu)) == 5) {
-				/* options_window() reads current configuration
+			} else if (ii == UI_MENU_EDIT_OPTIONS) { /* Edit cdw options */
+				/* preferences_window() reads current configuration
 				 * (saved in disk file), shows user a window
 				 * that allows him modify the options, save
 				 * options to disk file and to global variable
 				 * struct conf config */
-				options_window();
-				wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-				select_window(FALSE);
+				preferences_window();
 				fill_info();
-			}
-
-			/* Quit - Exit cdw */
-			if (item_index(current_item(menu)) == 6) {
+			} else if (ii == UI_MENU_EXIT_CDW) { /* Quit - Exit cdw */
 				/* this should be the same code as for q/Q hotkey above */
-				rv = dialogbox(_("Please confirm"), _("Do you really want to quit cdw?"), DIALOG_OK_CANCEL);
+				/* 2TRANS: this is title of dialog window asking user to confirm action */
+				rv = dialogbox(_("Please confirm"),
+					       /* 2TRANS: this is message in dialog window, user can press OK or Cancel */
+					       _("Do you really want to quit cdw?"), DIALOG_OK_CANCEL);
 				if (rv == BUTTON_OK) {
 					clean_before_cdw_exit();
 					exit(EXIT_SUCCESS);
 				}
+			} else {
+				;
+			}
 			}
-
 			break;
 		} /* switch(c) */
 		wrefresh(mainwin);
