@@ -17,18 +17,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-
 #define _GNU_SOURCE
 #include <signal.h>
 #include <string.h>
-#include <ctype.h> //isgraph()
-
 #include <stdio.h>
 #include <stdlib.h>
 
 #include <ncursesw/ncurses.h>
-#include <ncursesw/menu.h>
-#include <ncursesw/form.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -48,12 +43,9 @@
 #include "color.h"
 #include "gettext.h"
 #include "utils.h"
+#include "cdw_widgets.h"
 #include "cdrom_ctrl.h"
 
-// #include "cdw_ui.h"
-// #include "commands.h"
-// #include "cdw_tmp_files.h"
-
 
 
 extern struct conf config;
@@ -179,7 +171,7 @@ long long int _dirsize(char *path)
 			}
 		}
 
-		free(eps); // FIXME - this should be in 'if' or outside of 'if'?
+		free(eps); /* FIXME - this should be in 'if' or outside of 'if'? */
 		eps = NULL;
 	}
 
@@ -198,7 +190,7 @@ sig_atomic_t child_exit_status;
  */
 void clean_up_child_process(int signal_number)
 {
-	// clean child process
+	/* clean child process */
 	int status;
 	wait(&status);
 	child_exit_status = status;
@@ -228,6 +220,7 @@ void process_commandline_args(int argc, char *argv[])
 		lines = LINES - 2;
 		if ((LINES < 24) || (COLS < 79)) {
 			clean_before_cdw_exit();
+			/* 2TRANS: error message displayed when terminal requirements are not met */
 			printf(_("Needed min 80x25 terminal!"));
 			exit(-1);
 		}
@@ -236,12 +229,7 @@ void process_commandline_args(int argc, char *argv[])
 		exit(0);
 	}
 #endif
-#ifdef GTK_GUI
-	if ((strcmp((char *) argv[1], "--gui") == 0) || (strcmp((char *) argv[1], "-g") == 0)) {
-			gtk_gui(0, "");
-		exit(0);
-	}
-#endif
+
 	if ((strcmp((char *) argv[1], "--version") == 0) || (strcmp((char *) argv[1], "-v") == 0)) {
 		clean_before_cdw_exit();
 		printf("%s-%s (C) 2002-2003 Balazs Varkonyi\n\n", PACKAGE, VERSION);
@@ -250,20 +238,20 @@ void process_commandline_args(int argc, char *argv[])
 	}
 	if ((strcmp((char *) argv[1], "--help") == 0) || (strcmp((char *) argv[1], "-h") == 0)) {
 		endwin();
+		/* 2TRANS: %s is program name */
 		printf(_("Usage: %s [options]\n\n"), argv[0]);
 		printf(_("Options:\n\n"));
 #ifdef HAVE_LIBMYSQLCLIENT
 		printf(_("  --catalog | -c            : start in Disk Catalog mode\n"));
-#endif
-#ifdef GTK_GUI
-		printf(_("  --gui     | -g            : start cdw in GUI mode\n"));
 #endif
 		printf(_("  --help    | -h            : show this screen\n"));
 		printf(_("  --version | -v            : show version\n\n"));
 		clean_before_cdw_exit();
 		exit(0);
 	}
+	/* 2TRANS: first %s is program name, second - argument given to the program */
 	printf(_("%s: invalid option -- %s\n"), argv[0], argv[1]);
+	/* 2TRANS: %s is program name */
 	printf(_("Try `%s --help`\n"), argv[0]);
 	clean_before_cdw_exit();
 	exit(0);
@@ -295,17 +283,22 @@ int cdw_locale_init(void)
  * \param char *fullpath - full path to given file
  * \param int permissions - file permissions: S_IRUSR, S_IWUSR, S_IXUSR or logical sum
  * \param int filetype - CDW_FILE or CDW_DIR
- * \param struct stat *stbuf - allocated variable that will be filled with file information
+ * \param struct stat *finfo - allocated variable that will be filled with file information; caller can set it to NULL if he is not interested in file properties
  *
- * \returns 0 on success, -1 on failure
+ * \returns CDW_FILE_INVALID, CDW_PERM_ERROR, CDW_SYS_ERROR, CDW_OK;
  */
-int is_valid_path(char *fullpath, mode_t permissions, int filetype, struct stat *finfo)
+cdw_rv_t is_valid_path(char *fullpath, mode_t permissions, int filetype, struct stat *finfo)
 {
-	bool correct_type = false;
+	bool internal_finfo = false;
+	if (finfo == NULL) {
+		internal_finfo = true;
+		finfo = (struct stat *) malloc(sizeof(struct stat));
+
+	}
 
 	if (lstat(fullpath, finfo) == -1) { /* lstat failure */
-		fprintf(stderr, _("lstat failure\n"));
-		return -1;
+		/* fprintf(stderr, _("lstat failure\n")); */
+		return CDW_SYS_ERROR;
 	}
 
 	/* check type of file */
@@ -323,19 +316,90 @@ int is_valid_path(char *fullpath, mode_t permissions, int filetype, struct stat
 				return CDW_FILE_INVALID; /* not a dir */
 			}
 		default:
-			return CDW_FILE_INVALID; /* other file */
+			return CDW_FILE_INVALID; /* other problem related to filetype */
 	} /* switch */
 
 	/* check permissions */
 	if (permissions == -1) { /* don't ask for permissions */
-		return 0;
+		if (internal_finfo) {
+			free(finfo);
+			finfo = NULL;
+		}
+		return CDW_OK;
+	} else {
+		uid_t uid = geteuid();
+		bool user_perm = ((finfo->st_uid == uid) && ((finfo->st_mode & S_IRWXU) == permissions));
+
+		if (user_perm) {
+			if (internal_finfo) {
+				free(finfo);
+				finfo = NULL;
+			}
+			/* fprintf(stderr, "Correct permissions for selected file %s\n", fullpath); */
+			return CDW_OK;
+		} else {
+			if (internal_finfo) {
+				free(finfo);
+				finfo = NULL;
+			}
+			/* fprintf(stderr, "Wrong permissions for selected file %s\n", fullpath); */
+			return CDW_PERM_ERROR; /* wrong permissions */
+		}
+	}
+}
+
+
+
+/**
+ * Wrapper for is_valid_path() that asks user for valid path n times
+ *
+ * \param path - initial path, allocated string that an be modified by function
+ * \param filetype - type of file: CDW_DIR or CDW_FILE
+ * \param permissions - file permissions: S_IRUSR, S_IWUSR, S_IXUSR or logical sum; set to -1 if you don't want to check permissions
+ * \param n - how many times user can enter invalid path?
+ * \param title - title of dialog window
+ * \param promt - message displayed in dialog window
+ *
+ * \returns CDW_OK if user entered valid path,
+ *          CDW_CANCEL if user canceled entering the path,
+ *                     or the path was invalid in n tries
+ */
+cdw_rv_t get_valid_path(char *path, mode_t permissions, int filetype, int n, char *title, char *prompt)
+{
+	int i = 0;
+	for (i = 0; i < n; i++) {
+		cdw_rv_t rv = input_box(title, prompt, path, 0);
+
+		if (rv == CDW_OK) {
+			rv = is_valid_path(path, permissions, filetype, NULL);
+
+			if (rv == CDW_OK) {
+				return CDW_OK;
+			} else if (rv == CDW_PERM_ERROR) {
+				/* 2TRANS: this is dialog window title */
+				dialogbox(_("Message"),
+					  /* 2TRANS: this is error message in dialog window */
+					  _("Selected file has wrong permissions"), DIALOG_OK);
+				/* retry */
+			} else if (rv == CDW_FILE_INVALID) {
+				/* 2TRANS: this is dialog window title */
+				dialogbox(_("Message"),
+					  /* 2TRANS: this is error message in dialog window */
+					  _("Selected file is invalid"), DIALOG_OK);
+				/* retry */
+			} else {
+				/* 2TRANS: this is dialog window title */
+				dialogbox(_("Message"),
+					  /* 2TRANS: this is error message in dialog window - unknown error */
+					  _("Some error occured. Please retry."), DIALOG_OK);
+				/* retry */
+			}
+		} else { /* user abandoned action */
+			return CDW_CANCEL;
+		}
 	}
 
-	if ((finfo->st_mode & S_IRWXU) == permissions) { /* check only for USER permissions */
-		return 0;
-	} else {
-		return CDW_PERM_EROR; /* wrong permissions */
-	}
+	return CDW_CANCEL;
 }
 
 
@@ -361,44 +425,6 @@ int zombie_handler_init(void)
 
 
 
-#if 0 // this function probably will be no longer used, since we use wide characters ncurses libraries
-/**
- * Remove non-printable characters from path
- *
- * Replace non-printable characters (like '»') from file's path.
- * Such characters may be visible in files selector window, but
- * path containig such characters is not displayed by 'Selected files'
- * list, because it is implemented using ncurses MENU (and I don't know
- * how to fix it yet). Non-printable characters are replaced by '?'.
- *
- * It may be possible to replace thiese characters only in strings
- * displayed in 'Selected files' window and print them unaltered to
- * cdrecord-source-files-paths tmp file.
- *
- * \param char **string - pointer to path - this parameter may be modified by function
- *
- */
-void make_ncurses_printable_string(char **string)
-{
-
-	return;
-
-	int len = strlen(*string);
-
-	int i = 0;
-	for (i = 0; i < len; i++) {
-		if (! isprint(*((*string) + i))) {
-			(*((*string) + i)) = '?';
-			if (! isprint(*((*string) + i + 1))) {
-				i++;
-			}
-		}
-	}
-
-	return;
-}
-
-#endif // if 0
 
 /**
  * Get home directory
@@ -502,8 +528,10 @@ int get_tmp_dir(char **path)
 	/* some sane initial value */
 	strcpy(*path, "/tmp");
 
-
-	rv = input_box(_("Select directory"), _("Please select temporary directory.\n   Press ESC to skip."), *path, 0);
+	/* 2TRANS: this is title of dialog window */
+	rv = input_box(_("Select directory"),
+		       /* 2TRANS: this is message in dialog window. Please keep '\n'. */
+		       _("Please select temporary directory.\n   Press ESC to skip."), *path, 0);
 	if (rv == CDW_ESCAPE) {
 		return -1;
 	}
@@ -624,3 +652,113 @@ void my_itoa(int i, char *string)
 
 	return;
 }
+
+
+
+
+/* unused code below */
+#if 0 // this function probably will be no longer used, since we use wide characters ncurses libraries
+/**
+ * Remove non-printable characters from path
+ *
+ * Replace non-printable characters (like '»') from file's path.
+ * Such characters may be visible in files selector window, but
+ * path containig such characters is not displayed by 'Selected files'
+ * list, because it is implemented using ncurses MENU (and I don't know
+ * how to fix it yet). Non-printable characters are replaced by '?'.
+ *
+ * It may be possible to replace thiese characters only in strings
+ * displayed in 'Selected files' window and print them unaltered to
+ * cdrecord-source-files-paths tmp file.
+ *
+ * \param char **string - pointer to path - this parameter may be modified by function
+ *
+ */
+void make_ncurses_printable_string(char **string)
+{
+
+	return;
+
+	int len = strlen(*string);
+
+	int i = 0;
+	for (i = 0; i < len; i++) {
+		if (! isprint(*((*string) + i))) {
+			(*((*string) + i)) = '?';
+			if (! isprint(*((*string) + i + 1))) {
+				i++;
+}
+}
+}
+
+	return;
+}
+
+
+
+
+
+
+
+
+/* this is part of cdw_rv_t is_valid_path(char *fullpath, mode_t permissions, int filetype, struct stat *finfo),
+it should have checked for permission to access a file based on permissions of user OR group, but it does not work somehow for directories:
+user can't write to dir if it is in dir's group and permissions are d---rwx--- */
+if (permissions == -1) { /* don't ask for permissions */
+		if (internal_finfo) {
+			free(finfo);
+			finfo = NULL;
+}
+		return CDW_OK;
+} else {
+		uid_t uid = geteuid();
+		uid_t gid = getegid();
+		bool user_perm = ((finfo->st_uid == uid) && ((finfo->st_mode & S_IRWXU) == permissions));
+		/* shifting by one converts user permissions into group
+		 * permissions, additinal mask with S_IRWXG ensures that
+		* we check only group byte */
+		bool group_perm = ((finfo->st_gid == gid) && ((finfo->st_mode & S_IRWXG) == ((permissions >> 3) & S_IRWXG)));
+		fprintf(stderr, "\n\n");
+						if (group_perm) {
+						fprintf(stderr, "group perm = true\n");
+}
+						if (user_perm) {
+						fprintf(stderr, "user perm = true\n");
+}
+						fprintf(stderr, "stat group perm: %d, user perm: %d\n", (finfo->st_mode & S_IRWXG) >> 3, (finfo->st_mode & S_IRWXU) >> 6);
+						fprintf(stderr, "permissions variable, group: %d, user: %d\n", ((permissions >> 3) & S_IRWXG) >> 3, permissions >> 6);
+
+						if (user_perm || group_perm) {
+						if (internal_finfo) {
+						free(finfo);
+						finfo = NULL;
+}
+						fprintf(stderr, "Correct permissions for selected file %s\n", fullpath);
+						return CDW_OK;
+} else {
+						if (internal_finfo) {
+						free(finfo);
+						finfo = NULL;
+}
+						fprintf(stderr, "Wrong permissions for selected file %s\n", fullpath);
+						return CDW_PERM_ERROR; /* wrong permissions */
+}
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+#endif // if 0
+
+
+
