@@ -5,28 +5,36 @@
 #include <sys/stat.h>
 #include <dirent.h>
 
+#include "main.h" /* return values */
+
 enum {
 	CDW_FILE,
 	CDW_DIR
 } file_type;
 
+
 void process_commandline_args(int argc, char *argv[]);
 int cdw_locale_init(void);
 int zombie_handler_init(void);
-int one(const struct dirent *unused);
-void load_dir(char *dir, int width, int height);
+
+int add_to_dic();
+void after_event(char *message, int adddic);
+
+
+/* filesystem utils */
 long long dirsize(char **pathtable, int paths);
 long long _dirsize(char *dirpath);
-int is_valid_path(char *fullpath, mode_t permissions, int filetype, struct stat *finfo);
-int add_to_dic();
+int one(const struct dirent *unused);
+void load_dir(char *dir, int width, int height);
 int check_for_boot_image(void);
-void after_event(char *message, int adddic);
 int get_home_dir(char **path);
 int get_tmp_dir(char **path);
-/* void make_ncurses_printable_string(char **string); */
+cdw_rv_t is_valid_path(char *fullpath, mode_t permissions, int filetype, struct stat *finfo);
+cdw_rv_t get_valid_path(char *fullpath, mode_t permissions, int filetype, int n, char *title, char *prompt);
+
+/* string utils */
 char *rtrim(char *str);
 char *ltrim(char *str);
-
 char *concat(const char *str, ...);
 void my_itoa(int i, char *string);
 
